@@ -63,11 +63,6 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 
 				if !strings.Contains(body, "NOTOK") {
 					s1.Verified = true
-				} else {
-					// This function will check false positives for common test words, but also it will make sur>
-					if detectors.IsKnownFalsePositive(resMatch, detectors.DefaultFalsePositives, true) {
-						continue
-					}
 				}
 			}
 		}
