@@ -64,11 +64,6 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 				body := string(bodyBytes)
 				if (res.StatusCode >= 200 && res.StatusCode < 300) && strings.Contains(body, "owner=") {
 					s1.Verified = true
-				} else {
-					// This function will check false positives for common test words, but also it will make sure the key appears 'random' enough to be a real key.
-					if detectors.IsKnownFalsePositive(resMatch, detectors.DefaultFalsePositives, true) {
-						continue
-					}
 				}
 			}
 		}
