@@ -51,7 +51,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			Raw:          []byte(resMatch),
 		}
 		s1.ExtraData = map[string]string{
-			"rotation_guide": "https://howtorotate.com/docs/tutorials/ms/",
+			"rotation_guide": "https://howtorotate.com/docs/tutorials/microsoftteams/",
 		}
 
 		if verify {
