@@ -2,7 +2,6 @@ package sources
 
 import (
 	"bytes"
-	"io"
 	"math/rand"
 	"runtime"
 	"strings"
@@ -11,66 +10,10 @@ import (
 	"time"
 
 	"github.com/stretchr/testify/assert"
-	diskbufferreader "github.com/trufflesecurity/disk-buffer-reader"
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/context"
 )
 
-func TestChunker(t *testing.T) {
-	byteBuffer := bytes.NewBuffer(make([]byte, ChunkSize*9))
-	reReader, err := diskbufferreader.New(byteBuffer)
-	if err != nil {
-		t.Fatal(err)
-	}
-	defer reReader.Close()
-
-	baseChunks := make([]*Chunk, 0, 9)
-
-	chunkData, _ := io.ReadAll(reReader)
-	originalChunk := &Chunk{
-		Data: chunkData,
-	}
-
-	for chunk := range Chunker(originalChunk) {
-		baseChunks = append(baseChunks, chunk)
-	}
-
-	_ = reReader.Reset()
-
-	testChunks := make([]*Chunk, 0, 9)
-
-	testData, _ := io.ReadAll(reReader)
-	testOriginalChunk := &Chunk{
-		Data: testData,
-	}
-
-	for chunk := range Chunker(testOriginalChunk) {
-		testChunks = append(testChunks, chunk)
-	}
-
-	if len(testChunks) != len(baseChunks) {
-		t.Errorf("Wrong number of chunks received. Got %d, expected: %d.", len(testChunks), len(baseChunks))
-	}
-
-	for i, baseChunk := range baseChunks {
-		if !bytes.Equal(baseChunk.Data, testChunks[i].Data) {
-			t.Errorf("Chunk %d did not match expected. Got: %d bytes, expected: %d bytes", i+1, len(testChunks[i].Data), len(baseChunk.Data))
-		}
-	}
-}
-
-func BenchmarkChunker(b *testing.B) {
-	data := bytes.Repeat([]byte("a"), ChunkSize*100)
-	chunk := &Chunk{
-		Data: data,
-	}
-	b.ResetTimer()
-	for i := 0; i < b.N; i++ {
-		for range Chunker(chunk) {
-		}
-	}
-}
-
 func TestNewChunkedReader(t *testing.T) {
 	tests := []struct {
 		name       string
